RedbDatabase

Struct RedbDatabase 

pub struct RedbDatabase { /* private fields */ }
Redb-based persistent database for Safe Browsing

Implementations

Source

impl RedbDatabase

pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, DatabaseError>

Create a new redb database at the specified path

pub async fn init(&self) -> Result<(), DatabaseError>

Initialize the database and load cache

pub async fn with_max_age<P: AsRef<Path>>( path: P, max_age: Duration, ) -> Result<Self, DatabaseError>

Create a new redb database with a custom maximum age

pub fn default_path() -> Result<PathBuf, DatabaseError>

Get the default database path in the system cache directory