pub struct RedbDatabase { /* private fields */ }Expand description
Redb-based persistent database for Safe Browsing
Implementations
Sourceimpl RedbDatabase
impl RedbDatabase
Sourcepub fn new<P: AsRef<Path>>(path: P) -> Result<Self, DatabaseError>
pub fn new<P: AsRef<Path>>(path: P) -> Result<Self, DatabaseError>
Create a new redb database at the specified path
Sourcepub async fn init(&self) -> Result<(), DatabaseError>
pub async fn init(&self) -> Result<(), DatabaseError>
Initialize the database and load cache
Sourcepub async fn with_max_age<P: AsRef<Path>>(
path: P,
max_age: Duration,
) -> Result<Self, DatabaseError>
pub async fn with_max_age<P: AsRef<Path>>( path: P, max_age: Duration, ) -> Result<Self, DatabaseError>
Create a new redb database with a custom maximum age
Sourcepub fn default_path() -> Result<PathBuf, DatabaseError>
pub fn default_path() -> Result<PathBuf, DatabaseError>
Get the default database path in the system cache directory